==> zzyj-outputvalcount-impl-3.0.0-20250801.034647-367-sources.jar: com/ejianc/business/worklog/controller/OrgIndexSubmitController.java <==
package com.ejianc.business.worklog.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.worklog.bean.OrgIndexSubmitEntity;
import com.ejianc.business.worklog.service.IOrgIndexSubmitService;
import com.ejianc.business.worklog.vo.OrgIndexSubmitVO;

/**
 * 指标线上化-指标报送
 *
 * @author generator
 */
@Controller
@RequestMapping("orgIndexSubmit")
public class OrgIndexSubmitController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IOrgIndexSubmitService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OrgIndexSubmitVO> saveOrUpdate(@RequestBody OrgIndexSubmitVO saveOrUpdateVO) {
        OrgIndexSubmitEntity entity = BeanMapper.map(saveOrUpdateVO, OrgIndexSubmitEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改删除本行或者上一行
            } else {
                throw new BusinessException("网络异常，编码生成失败，请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);

        /**
         * 内码生成
         */
        if (entity.getPid() != null) {
            OrgIndexSubmitEntity pEntity = service.selectById(entity.getPid());
            String innerCode = pEntity.getInnerCode();
            String innerName = pEntity.getInnerName();
            entity.setInnerCode(innerCode + "-" + entity.getId().toString());
            entity.setInnerName(innerName + "-" + entity.getIndexName());

        } else {
            entity.setInnerCode(entity.getId().toString());
            entity.setInnerName(entity.getIndexName());
        }
        service.saveOrUpdate(entity);
        OrgIndexSubmitVO vo = BeanMapper.map(entity, OrgIndexSubmitVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OrgIndexSubmitVO> queryDetail(Long id) {
        OrgIndexSubmitEntity entity = service.selectById(id);
        OrgIndexSubmitVO vo = BeanMapper.map(entity, OrgIndexSubmitVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OrgIndexSubmitVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (OrgIndexSubmitVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(OrgIndexSubmitVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OrgIndexSubmitVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("indexName");
        fuzzyFields.add("indexType");
        fuzzyFields.add("dutyPersonName");
        fuzzyFields.add("manageType");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();
        //当前应用有权限的根orgId，以逗号分割，可据此查询其本下数据，需判空
        String authOrgIds = userContextCache.getAuthOrgIds();
        List<OrgVO> orgVOList = null;
        if (StringUtils.isNotBlank(authOrgIds)) {//移动端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentIds(Arrays.stream(authOrgIds.split(",")).map(Long::parseLong).collect(Collectors.toList())), true, "查询失败，获取当前本下组织信息失败。");
        } else {//pc端查询
            orgVOList = (List<OrgVO>) getRespData(iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()), true, "查询失败，获取当前本下组织信息失败。");
        }
        //普通组织 id
        List<Long> commonOrgIds = new ArrayList<>();
        //项目部 id
        List<Long> departmentIds = new ArrayList<>();
        orgVOList.stream().forEach(org -> {
            commonOrgIds.add(org.getId());

        });
        if (CollectionUtils.isNotEmpty(commonOrgIds)) {
            /** 要求主表有orgId字段，保存单据所属组织 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, commonOrgIds));
        } else if (CollectionUtils.isNotEmpty(departmentIds)) {
            /** 要求主表有projectDepartmentId字段，保存单据所属项目部 */
            param.getParams().put("orgId", new Parameter(QueryParam.IN, departmentIds));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */


        int pageSize = param.getPageSize();
        int pageIndex = param.getPageIndex();

        List<OrgIndexSubmitEntity> allData = service.queryList(param);
        List<OrgIndexSubmitVO> records = BeanMapper.mapList(allData, OrgIndexSubmitVO.class);
        /**
         * 树形显示
         */
        List<OrgIndexSubmitVO> parentVOS = records.stream().filter(s -> s.getPid() == null).collect(Collectors.toList());
        for (OrgIndexSubmitVO vo : parentVOS) {
            vo.setChildren(getWorkTypeTree(vo.getId(), records));
        }


        IPage<OrgIndexSubmitVO> pageData = new Page<>(pageIndex, pageSize, parentVOS.size());

        pageData.setRecords(parentVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 递归放入
     */
    private List<OrgIndexSubmitVO> getWorkTypeTree(Long parentNodeId, List<OrgIndexSubmitVO> records) {
        List<OrgIndexSubmitVO> resultList = new ArrayList<>();
        List<OrgIndexSubmitVO> childrenList = records.stream().filter(s -> parentNodeId.equals(s.getPid())).collect(Collectors.toList());
        if (ListUtil.isNotEmpty(childrenList)) {
            for (OrgIndexSubmitVO child : childrenList) {
                child.setChildren(getWorkTypeTree(child.getId(), records));
                resultList.add(child);
            }
        }
        if (ListUtil.isNotEmpty(resultList)) {
            return resultList;
        } else {
            return null;
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<OrgIndexSubmitEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("OrgIndexSubmit-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refOrgIndexSubmitData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OrgIndexSubmitVO>> refOrgIndexSubmitData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                         String condition,
                                                                         String searchObject,
                                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }



        List<OrgIndexSubmitEntity> allData = service.queryList(param);
        List<OrgIndexSubmitVO> records = BeanMapper.mapList(allData, OrgIndexSubmitVO.class);
        /**
         * 树形显示
         */
        List<OrgIndexSubmitVO> parentVOS = records.stream().filter(s -> s.getPid() == null).collect(Collectors.toList());
        for (OrgIndexSubmitVO vo : parentVOS) {
            vo.setChildren(getWorkTypeTree(vo.getId(), records));
        }
        IPage<OrgIndexSubmitVO> pageData = new Page<>(pageNumber, pageSize, parentVOS.size());

        pageData.setRecords(parentVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }
}

==> zzyj-outputvalcount-impl-3.0.0-20250925.101923-377-sources.jar: com/ejianc/business/worklog/controller/OrgIndexSubmitController.java <==
package com.ejianc.business.worklog.controller;

import java.io.Serializable;

import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;

import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;

import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.worklog.bean.OrgIndexSubmitEntity;
import com.ejianc.business.worklog.service.IOrgIndexSubmitService;
import com.ejianc.business.worklog.vo.OrgIndexSubmitVO;

/**
 * 指标线上化-指标报送
 *
 * @author generator
 */
@Controller
@RequestMapping("orgIndexSubmit")
public class OrgIndexSubmitController implements Serializable {
    private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private IOrgIndexSubmitService service;

    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<OrgIndexSubmitVO> saveOrUpdate(@RequestBody OrgIndexSubmitVO saveOrUpdateVO) {
        OrgIndexSubmitEntity entity = BeanMapper.map(saveOrUpdateVO, OrgIndexSubmitEntity.class);
        UserContext userContextCache = sessionManager.getUserContext();
        if (entity.getId() == null || entity.getId() == 0) {
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE, InvocationInfoProxy.getTenantid(), saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if (billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改删除本行或者上一行
            } else {
                throw new BusinessException("网络异常，编码生成失败，请稍后再试");
            }
        } else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
        service.saveOrUpdate(entity, false);

        /**
         * 内码生成
         */
        if (entity.getPid() != null) {
            OrgIndexSubmitEntity pEntity = service.selectById(entity.getPid());
            String innerCode = pEntity.getInnerCode();
            String innerName = pEntity.getInnerName();
            entity.setInnerCode(innerCode + "-" + entity.getId().toString());
            entity.setInnerName(innerName + "-" + entity.getIndexName());

        } else {
            entity.setInnerCode(entity.getId().toString());
            entity.setInnerName(entity.getIndexName());
        }
        service.saveOrUpdate(entity);
        OrgIndexSubmitVO vo = BeanMapper.map(entity, OrgIndexSubmitVO.class);
        return CommonResponse.success("保存或修改单据成功！", vo);
    }

    /**
     * @param id
     * @Description queryDetail 查询详情
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<OrgIndexSubmitVO> queryDetail(Long id) {
        OrgIndexSubmitEntity entity = service.selectById(id);
        OrgIndexSubmitVO vo = BeanMapper.map(entity, OrgIndexSubmitVO.class);
        return CommonResponse.success("查询详情数据成功！", vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<OrgIndexSubmitVO> vos) {
        if (ListUtil.isNotEmpty(vos)) {
            for (OrgIndexSubmitVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(OrgIndexSubmitVO::getId).collect(Collectors.toList()), true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @param param
     * @Description queryList 查询列表
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<OrgIndexSubmitVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.add("indexName");
        fuzzyFields.add("indexType");
        fuzzyFields.add("dutyPersonName");
        fuzzyFields.add("manageType");
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        UserContext userContextCache = sessionManager.getUserContext();

        Long deptId = userContextCache.getDeptId();
        String deptName = userContextCache.getDeptName();
        if(!"企业管理与发展部".equals(deptName)){
            param.getParams().put("departmentId", new Parameter(QueryParam.EQ, deptId));
        }
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */
        int pageSize = param.getPageSize();
        int pageIndex = param.getPageIndex();

        List<OrgIndexSubmitEntity> allData = service.queryList(param);
        List<OrgIndexSubmitVO> records = BeanMapper.mapList(allData, OrgIndexSubmitVO.class);
        /**
         * 树形显示
         */
        List<OrgIndexSubmitVO> parentVOS = records.stream().filter(s -> s.getPid() == null).collect(Collectors.toList());
        for (OrgIndexSubmitVO vo : parentVOS) {
            vo.setChildren(getWorkTypeTree(vo.getId(), records));
        }


        IPage<OrgIndexSubmitVO> pageData = new Page<>(pageIndex, pageSize, parentVOS.size());

        pageData.setRecords(parentVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }

    /**
     * 递归放入
     */
    private List<OrgIndexSubmitVO> getWorkTypeTree(Long parentNodeId, List<OrgIndexSubmitVO> records) {
        List<OrgIndexSubmitVO> resultList = new ArrayList<>();
        List<OrgIndexSubmitVO> childrenList = records.stream().filter(s -> parentNodeId.equals(s.getPid())).collect(Collectors.toList());
        if (ListUtil.isNotEmpty(childrenList)) {
            for (OrgIndexSubmitVO child : childrenList) {
                child.setChildren(getWorkTypeTree(child.getId(), records));
                resultList.add(child);
            }
        }
        if (ListUtil.isNotEmpty(resultList)) {
            return resultList;
        } else {
            return null;
        }
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if (isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @param param
     * @Description 导出
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId", new Parameter(QueryParam.IN, iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<OrgIndexSubmitEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("OrgIndexSubmit-export.xlsx", beans, response);
    }

    /**
     * @param param
     * @Description 参照
     * @Return void
     */
    @RequestMapping(value = "/refOrgIndexSubmitData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<OrgIndexSubmitVO>> refOrgIndexSubmitData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                         String condition,
                                                                         String searchObject,
                                                                         String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if (StringUtils.isNotEmpty(condition)) {
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }



        List<OrgIndexSubmitEntity> allData = service.queryList(param);
        List<OrgIndexSubmitVO> records = BeanMapper.mapList(allData, OrgIndexSubmitVO.class);
        /**
         * 树形显示
         */
        List<OrgIndexSubmitVO> parentVOS = records.stream().filter(s -> s.getPid() == null).collect(Collectors.toList());
        for (OrgIndexSubmitVO vo : parentVOS) {
            vo.setChildren(getWorkTypeTree(vo.getId(), records));
        }
        IPage<OrgIndexSubmitVO> pageData = new Page<>(pageNumber, pageSize, parentVOS.size());

        pageData.setRecords(parentVOS);
        return CommonResponse.success("查询列表数据成功！", pageData);
    }
}
